ScriptError

Enum ScriptError 

pub enum ScriptError {
    ScriptNotFound(Byte32),
    ExceededMaximumCycles(Cycle),
    CyclesOverflow(Cycle, Cycle),
    MultipleMatches,
    ValidationFailure(String, i8),
    EncounteredKnownBugs(String, usize),
    InvalidScriptHashType(String),
    InvalidVmVersion(u8),
    VMInternalError(Error),
    Interrupts,
    Other(String),
}
Script execution error.

Variants



ScriptNotFound(Byte32)

The field code_hash in script can’t be resolved



ExceededMaximumCycles(Cycle)

The script consumes too much cycles



CyclesOverflow(Cycle, Cycle)

Internal error cycles overflow



MultipleMatches

script.type_hash hits multiple cells with different data



ValidationFailure(String, i8)

Non-zero exit code returns by script



EncounteredKnownBugs(String, usize)

Known bugs are detected in transaction script outputs



InvalidScriptHashType(String)

InvalidScriptHashType



InvalidVmVersion(u8)

InvalidVmVersion



VMInternalError(Error)

Errors thrown by ckb-vm



Interrupts

Interrupts, such as a Ctrl-C signal



Other(String)

Other errors raised in script execution process

Implementations

Source

impl ScriptError

pub fn validation_failure(script: &Script, exit_code: i8) -> ScriptError

Creates a script error originated the script and its exit code.

pub fn source(self, script_group: &ScriptGroup) -> TransactionScriptError

Creates a script error originated from the script group.

pub fn input_lock_script(self, index: usize) -> TransactionScriptError

Creates a script error originated from the lock script of the input cell at the specific index.

pub fn input_type_script(self, index: usize) -> TransactionScriptError

Creates a script error originated from the type script of the input cell at the specific index.

pub fn output_type_script(self, index: usize) -> TransactionScriptError

Creates a script error originated from the type script of the output cell at the specific index.

pub fn unknown_source(self) -> TransactionScriptError

Creates a script error with unknown source, usually a internal error