Struct ckb_script::TxVerifyEnv [−][src]
pub struct TxVerifyEnv { /* fields omitted */ }Expand description
The environment that transactions are in.
Implementations
The transaction has just been submitted.
The input is current tip header.
The transaction has already been proposed before several blocks.
The input is current tip header and how many blocks have been passed since the transaction was proposed.
The transaction will committed in current block.
The input is current tip header.
The block number of the earliest block which the transaction will committed in.
The epoch number of the earliest epoch which the transaction will committed in.
The parent block hash of the earliest block which the transaction will committed in.
The earliest epoch which the transaction will committed in.